==> lxqt-config-1.0.0.tar.xz: lxqt-config-1.0.0/lxqt-config-brightness/translations/lxqt-config-brightness_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Pengaturan Kecerahan</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished">&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pengatur lampu latar dan kecerahan:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Lampu latar</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Kecerahan</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Konfirmasi diperlukan setelah pengaturan diubah</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="112"/>
        <source>Brightness settings changed</source>
        <translation>Pengaturan kecerahan diubah</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="113"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Konfirmasi diperlukan. Apakah pengaturannya benar?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Keluaran:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="68"/>
        <source>Increase brightness.</source>
        <translation>Meningkatkan kecerahan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Decrease brightness.</source>
        <translation>Menurunkan kecerahan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Mengatur kecerahan dari 1 sampai 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Reset gamma to default value.</source>
        <translation>Setel ulang gamma ke nilai awal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="112"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Tidak dapat menaikkan/menurunkan dan set dalam hubungannya</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="117"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Tidak dapat menggunakan opsi menaikkan dan menurunkan bersamaan</translation>
    </message>
</context>
</TS>

==> lxqt-config-2.2.0.tar.xz: lxqt-config-2.2.0/lxqt-config-brightness/translations/lxqt-config-brightness_id.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>BrightnessSettings</name>
    <message>
        <location filename="../brightnesssettings.ui" line="14"/>
        <source>Brightness Settings</source>
        <translation>Pengaturan Kecerahan</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="35"/>
        <location filename="../brightnesssettings.ui" line="74"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="42"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Backlight and brightness settings:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Pengatur lampu latar dan kecerahan:&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="51"/>
        <source>Backlight</source>
        <translation>Lampu latar</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="57"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="87"/>
        <source>Brightness</source>
        <translation>Kecerahan</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.ui" line="105"/>
        <source>Require confirmation after settings change</source>
        <translation>Konfirmasi diperlukan setelah pengaturan diubah</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="115"/>
        <source>Brightness settings changed</source>
        <translation>Pengaturan kecerahan diubah</translation>
    </message>
    <message>
        <location filename="../brightnesssettings.cpp" line="116"/>
        <source>Confirmation required. Are the settings correct?</source>
        <translation>Konfirmasi diperlukan. Apakah pengaturannya benar?</translation>
    </message>
</context>
<context>
    <name>OutputWidget</name>
    <message>
        <location filename="../outputwidget.ui" line="38"/>
        <source>&lt;b&gt;Output:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Keluaran:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="48"/>
        <source>☼</source>
        <translation>☼</translation>
    </message>
    <message>
        <location filename="../outputwidget.ui" line="80"/>
        <source>☀</source>
        <translation>☀</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Increase brightness.</source>
        <translation>Meningkatkan kecerahan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="72"/>
        <source>Decrease brightness.</source>
        <translation>Menurunkan kecerahan.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>Set brightness from 1 to 100.</source>
        <translation>Mengatur kecerahan dari 1 sampai 100.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>Reset gamma to default value.</source>
        <translation>Setel ulang gamma ke nilai awal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="114"/>
        <source>%1: Can&apos;t use increase/decrease and set in conjunction</source>
        <translation>%1: Tidak dapat menaikkan/menurunkan dan set dalam hubungannya</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="119"/>
        <source>%1: Can&apos;t use increase and decrease options in conjunction</source>
        <translation>%1: Tidak dapat menggunakan opsi menaikkan dan menurunkan bersamaan</translation>
    </message>
</context>
</TS>
